<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Devices.Sms

Windows Runtime (WinRT) APIs for for the `Windows.Devices.Sms` namespace.

This package provides the `winrt.windows.devices.sms` module.
